@@ -1,4 +1,5 @@
 #!/usr/bin/env python3
+# __main__.py
 
 """Awesome Check Links 
 
@@ -16,8 +17,7 @@ Options:
 
 """
 
-from aclinks import aclinks as acl
-from pprint import pprint
+from aclinks import aclinks
 from docopt import docopt 
  
 
@@ -37,14 +37,14 @@ if __name__ == "__main__":
         print("aclinks take only md file ! ")
         exit()
 
-    links = acl.extract_links(__file)
+    links = aclinks.extract_links(__file)
     
 
     if __down:
-        down_links = acl.get_down_links(__file, links,__verbose, __exit)        
+        down_links = aclinks.get_down_links(__file, links,__verbose, __exit)        
     
     else : 
-        acl.get_all_status(__file, links,__verbose, __exit)
+        aclinks.get_all_status(__file, links,__verbose, __exit)
 
 
     
\ No newline at end of file
